@@ -52,13 +52,12 @@ import jakarta.servlet.http.HttpServletResponse;
 import org.apache.catalina.WebResource;
 import org.apache.catalina.connector.RequestFacade;
 import org.apache.catalina.util.DOMWriter;
-import org.apache.catalina.util.URLEncoder;
 import org.apache.catalina.util.XMLWriter;
+import org.apache.tomcat.util.buf.HexUtils;
 import org.apache.tomcat.util.http.ConcurrentDateFormat;
 import org.apache.tomcat.util.http.FastHttpDateFormat;
 import org.apache.tomcat.util.http.RequestUtil;
 import org.apache.tomcat.util.security.ConcurrentMessageDigest;
-import org.apache.tomcat.util.security.MD5Encoder;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
@@ -140,15 +139,6 @@ public class WebdavServlet extends DefaultServlet {
 
     // -------------------------------------------------------------- Constants
 
-    private static final URLEncoder URL_ENCODER_XML;
-    static {
-        URL_ENCODER_XML = (URLEncoder) URLEncoder.DEFAULT.clone();
-        // Remove '&' from the safe character set since while it it permitted
-        // in a URI path, it is not permitted in XML and encoding it is a simple
-        // way to address this.
-        URL_ENCODER_XML.removeSafeCharacter('&');
-    }
-
     private static final String METHOD_PROPFIND = "PROPFIND";
     private static final String METHOD_PROPPATCH = "PROPPATCH";
     private static final String METHOD_MKCOL = "MKCOL";
@@ -390,18 +380,6 @@ public class WebdavServlet extends DefaultServlet {
     }
 
 
-    /**
-     * URL rewriter.
-     *
-     * @param path Path which has to be rewritten
-     * @return the rewritten path
-     */
-    @Override
-    protected String rewriteUrl(String path) {
-        return URL_ENCODER_XML.encode(path, StandardCharsets.UTF_8);
-    }
-
-
     /**
      * Override the DefaultServlet implementation and only use the PathInfo. If
      * the ServletPath is non-null, it will be because the WebDAV servlet has
@@ -892,9 +870,7 @@ public class WebdavServlet extends DefaultServlet {
 
         int lockDuration = DEFAULT_TIMEOUT;
         String lockDurationStr = req.getHeader("Timeout");
-        if (lockDurationStr == null) {
-            lockDuration = DEFAULT_TIMEOUT;
-        } else {
+        if (lockDurationStr != null) {
             int commaPos = lockDurationStr.indexOf(',');
             // If multiple timeouts, just use the first
             if (commaPos != -1) {
@@ -1070,7 +1046,7 @@ public class WebdavServlet extends DefaultServlet {
                     lock.depth + "-" + lock.owner + "-" + lock.tokens + "-" +
                     lock.expiresAt + "-" + System.currentTimeMillis() + "-" +
                     secret;
-            String lockToken = MD5Encoder.encode(ConcurrentMessageDigest.digestMD5(
+            String lockToken = HexUtils.toHexString(ConcurrentMessageDigest.digestMD5(
                     lockTokenStr.getBytes(StandardCharsets.ISO_8859_1)));
 
             if (resource.isDirectory() && lock.depth == maxDepth) {
@@ -1080,9 +1056,11 @@ public class WebdavServlet extends DefaultServlet {
                 // Checking if a child resource of this collection is
                 // already locked
                 List<String> lockPaths = new ArrayList<>();
-                for (LockInfo currentLock : collectionLocks) {
+                Iterator<LockInfo> collectionLocksIterator = collectionLocks.iterator();
+                while (collectionLocksIterator.hasNext()) {
+                    LockInfo currentLock = collectionLocksIterator.next();
                     if (currentLock.hasExpired()) {
-                        resourceLocks.remove(currentLock.path);
+                        collectionLocksIterator.remove();
                         continue;
                     }
                     if (currentLock.path.startsWith(lock.path) &&
